# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-04-06 22:29
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('journal', '0003_journal_version'),
    ]

    operations = [
        migrations.AddField(
            model_name='journal',
            name='modified',
            field=models.DateTimeField(auto_now=True),
        ),
    ]
